@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import typing as t
-from functools import cache, reduce
+from functools import lru_cache, reduce
 from os.path import abspath
 from random import random
 
@@ -149,7 +149,7 @@ class ShuffleConfig:
         with open(self.path, "w") as f:
             f.write(self.generate())
 
-    @cache
+    @lru_cache()
     def __hex_convert(self, integer: int) -> str:
         converted = hex(integer).upper()
         while len(converted) < 18:
@@ -317,7 +317,8 @@ class ShuffleConfig:
         Takes the items in the ShuffleConfig
         and stacks them up to a cycle slot n in random order.
         """
-        for item_slot, item_ids in self._slotmap:
+        slotmap_copy = SlotMap([*self._slotmap])
+        for item_slot, item_ids in slotmap_copy:
             depending_itemslots = get_depending_item_slots(item_slot)
 
             if not item_ids:
